-- | This demonstrates a BUG.
module Foo () where
